import Accordion from "@/components/Accordion"
import Breadcrumbs from "@/components/Breadcrumbs";
import SearchFaqInput from "@/components/faq/blocks/SearchFaqInput"
import { mergeClassNames } from "@/helpers"
import useFaqs from "@/hooks/useFaq"
import { Metadata } from "next";

export const metadata: Metadata = {
	metadataBase: new URL(process.env.NEXT_PUBLIC_APP_URL ?? ""),
	applicationName: "ReadyforWork Help Center",
	title: 'Help Center - Business',
	description: "Learn in-demand digital skills to future-proof your career: digital marketing, UX/UI, data science, software engineering, financial analysis. Work on your business ideas.",

	openGraph: {
		title: 'Help Center - Business | Learn in-demand digital skills',
		description: "Learn in-demand digital skills to future-proof your career: digital marketing, UX/UI, data science, software engineering, financial analysis. Work on your business ideas.",
		url: process.env.NEXT_PUBLIC_APP_URL,
		siteName: 'Help Center ReadyforWork | Learn in-demand digital skills',
		images: "https://res.cloudinary.com/sfan/image/upload/v1684836444/education-meta-image_jc7z8z.jpg",
		type: 'website',
	},
	twitter: {
		card: 'summary_large_image',
		title: 'Help Center - Business | Learn in-demand digital skills',
		description: "Learn in-demand digital skills to future-proof your career: digital marketing, UX/UI, data science, software engineering, financial analysis. Work on your business ideas.",
		images: ['https://res.cloudinary.com/sfan/image/upload/v1684836444/education-meta-image_jc7z8z.jpg'],
	},
	alternates: {
		canonical: process.env.NEXT_PUBLIC_APP_URL,
	}
};

export default function BusinessFaq() {

	const businessFaqs = useFaqs("business")

	return (
		<main className={mergeClassNames(
			" max-w-7xl overflow-x-hidden px-10 md:px-24 pb-10 md:pb-24 py-4 mx-auto",
			"flex flex-col gap-10"
		)}>

			<Breadcrumbs pages={
				[
					{
						title: "Business",
						href: "#"
					}
				]
			} />
			<section className="max-w-md w-full mx-auto">
				<h3 className="text-center font-semibold p-1 text-gray-300">Topic: Business</h3>
				<SearchFaqInput
					topic="business"
					placeholder="If you've got a question, type it here."
				/>
			</section>
			<div className="max-w-4xl  min-w-full mx-auto md:px-48 space-y-5">
				{
					businessFaqs.map((faq, idx) => (

						<Accordion
							key={"business-faq-" + idx}
							title={faq.title}
							body={faq.text}
						/>
					)
					)
				}
			</div>
		</main>
	)
}
